pub struct Keychain {
client: Arc<HTTPClient>,
supervisor: Arc<Supervisor>,
con: Arc<ConsoleMessenger>,
f_cont: Arc<RwLock<FlightComputer>>,
t_cont: Arc<TaskController>,
c_cont: Arc<CameraController>,
}Expand description
Struct representing the key components of the application, providing access to various subsystems such as the HTTP client, camera controller, flight computer, task controller, and console messenger.
Fields
client: Arc<HTTPClient>The HTTP client for performing network requests.
supervisor: Arc<Supervisor>The supervisor listening for new objectives, refreshing observation, …
con: Arc<ConsoleMessenger>The console messenger for handling console-related operations.
f_cont: Arc<RwLock<FlightComputer>>The flight computer responsible for managing satellite operations.
t_cont: Arc<TaskController>The task controller for scheduling and managing tasks.
c_cont: Arc<CameraController>The camera controller for handling camera-related operations.
Implementations
Sourceimpl Keychain
impl Keychain
Sourcepub async fn new(
url: &str,
) -> (Self, Receiver<KnownImgObjective>, Receiver<BeaconObjective>)
pub async fn new( url: &str, ) -> (Self, Receiver<KnownImgObjective>, Receiver<BeaconObjective>)
Sourcepub fn client(&self) -> Arc<HTTPClient>
pub fn client(&self) -> Arc<HTTPClient>
Provides a cloned reference to the HTTP client.
Sourcepub fn supervisor(&self) -> Arc<Supervisor>
pub fn supervisor(&self) -> Arc<Supervisor>
Provides a cloned reference to the supervisor
Sourcepub fn f_cont(&self) -> Arc<RwLock<FlightComputer>>
pub fn f_cont(&self) -> Arc<RwLock<FlightComputer>>
Provides a cloned reference to the flight computer.
Sourcepub fn t_cont(&self) -> Arc<TaskController>
pub fn t_cont(&self) -> Arc<TaskController>
Provides a cloned reference to the task controller.
Sourcepub fn con(&self) -> Arc<ConsoleMessenger>
pub fn con(&self) -> Arc<ConsoleMessenger>
Provides a cloned reference to the console messenger.
Sourcepub fn c_cont(&self) -> Arc<CameraController>
pub fn c_cont(&self) -> Arc<CameraController>
Provides a cloned reference to the camera controller.